@@ -12,10 +12,11 @@ from openapi_schema_pydantic import (
     Server,
     Tag,
 )
-from pydantic import AnyUrl, BaseModel, DirectoryPath
+from pydantic import AnyUrl, BaseModel, DirectoryPath, constr
 from typing_extensions import Type
 
 from starlite.openapi.controller import OpenAPIController
+from starlite.template import TemplateEngineProtocol
 
 
 class CORSConfig(BaseModel):
@@ -68,6 +69,14 @@ class OpenAPIConfig(BaseModel):
 
 
 class StaticFilesConfig(BaseModel):
-    path: str
+    path: constr(min_length=1)  # type: ignore
     directories: List[DirectoryPath]
     html_mode: bool = False
+
+
+class TemplateConfig(BaseModel):
+    class Config:
+        arbitrary_types_allowed = True
+
+    directory: Union[DirectoryPath, List[DirectoryPath]]
+    engine: Type[TemplateEngineProtocol]
